@@ -1,7 +1,7 @@
 /**
  * a class which implements a simple counter
  *
- * @version	$Id: Counter.java,v 1.1 2002/11/05 12:14:02 nthiery Exp $
+ * @version	$Id: Counter.java,v 1.2 2003/02/19 15:16:39 nthiery Exp $
  * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
 **/
 
@@ -24,7 +24,7 @@ class Counter {
      * @return
      **/
     public void increase() {
-	i=i;
+	i=i+1;
     }
 
     /**
