@@ -1,7 +1,7 @@
 /**
  * a class for storing a move on a Queens game
  *
- * @version	$Id: Move.java,v 1.2 2002/11/27 22:16:24 nthiery Exp $
+ * @version	$Id: Move.java,v 1.4 2003/02/19 15:16:57 nthiery Exp $
  * @author	Nicolas M. Thiry <nthiery@users.sourceforge.net>
 **/
 
@@ -15,7 +15,7 @@ public class Move {
     public int [] ypos;
 
     /**
-     * Constructor for a simple move without intermediate positions.
+     * Constructor for a simple move without intermediate positions
      *
      * @param x1, y1, x2, y2	positive integers
      **/
@@ -24,7 +24,7 @@ public class Move {
     }
 
     /**
-     * Constructor for a complex move
+     * Constructor for a complex move with intermediate positions
      *
      * @param x, y	arrays of positive integers
      **/
@@ -40,4 +40,15 @@ public class Move {
     public Move(String move) {
 	throw new RuntimeException("Not Implemented");
     }
+
+    /**
+     * Convert a move into a string such as "A2-C4-A6"
+     *
+     * @param
+     * @return a string
+     **/
+    public String toString() {
+	// Note: the examples in AsciiDemo might help to implement this method
+	throw new RuntimeException("Not Implemented");
+    }
 }
